"use client"
import React, { useState } from 'react';

function FAQ() {
  const [activeIndex, setActiveIndex] = useState(null); // State to track the active question

  const toggleFAQ = (index:any) => {
    if (activeIndex === index) {
      setActiveIndex(null); // Close if clicked again
    } else {
      setActiveIndex(index); // Open the clicked FAQ
    }
  };

  const faqData = [
    { question: 'What cloud solutions does H-Dot provide?', answer: 'H-Dot specializes in cloud solutions across platforms like AWS, Azure, and Google Cloud Platform (GCP). We design and implement strategies to optimize cloud performance, scalability, and cost efficiency tailored to your business needs.' },
    { question: 'How does H-Dot approach DevOps?', answer: 'Our DevOps services integrate development and operations to enhance collaboration and efficiency. We utilize tools like CI/CD pipelines and automation to streamline processes and ensure faster delivery cycles.' },
    { question: 'What is the typical timeline for a project?', answer: 'Project timelines can vary based on scope and complexity, but we work to establish clear milestones and deliverables, ensuring transparency throughout the process.' },
    { question: 'How does H-Dot ensure data security?', answer: 'We implement stringent security measures, including encryption, access controls, and regular audits, to protect your data across all systems and platforms.' },
    { question: 'How do I get started with H-Dot?', answer: 'Getting started is simple! Reach out to us via our contact page to schedule a consultation, and we’ll guide you through our process to identify the best solutions for your business.' },

  ];

  return (
    <section className="py-10 bg-gray-50 sm:py-16 lg:py-24">
      <div className="px-4 mx-auto sm:px-6 lg:px-8 max-w-7xl">
        <div className="max-w-2xl mx-auto text-center">
          <h2 className="text-3xl font-bold leading-tight text-black sm:text-4xl lg:text-5xl">
            Frequently Asked Questions
          </h2>
          <p className="max-w-xl mx-auto mt-4 text-base leading-relaxed text-gray-600">
            Amet minim mollit non deserunt ullamco est sit aliqua dolor do
          </p>
        </div>

        <div className="max-w-3xl mx-auto mt-8 space-y-4 md:mt-16">
          {faqData.map((item, index) => (
            <div
              key={index}
              className={`transition-all duration-200 bg-white border border-gray-200 shadow-lg cursor-pointer hover:bg-gray-50 ${
                activeIndex === index ? 'bg-gray-50' : ''
              }`}
            >
              <button
                type="button"
                className="flex items-center justify-between w-full px-4 py-5 sm:p-6"
                onClick={() => toggleFAQ(index)}
              >
                <span className="flex text-lg font-semibold text-black">
                  {item.question}
                </span>
                <svg
                  className={`w-6 h-6 text-gray-400 transform ${
                    activeIndex === index ? 'rotate-180' : ''
                  }`}
                  xmlns="http://www.w3.org/2000/svg"
                  fill="none"
                  viewBox="0 0 24 24"
                  stroke="currentColor"
                >
                  <path
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    strokeWidth="2"
                    d="M19 9l-7 7-7-7"
                  />
                </svg>
              </button>
              {activeIndex === index && (
                <div className="px-4 pb-5 sm:px-6 sm:pb-6">
                  <p>
                    {item.answer}{' '}
  
                  </p>
                </div>
              )}
            </div>
          ))}
        </div>

        <p className="text-center text-gray-600 textbase mt-9">
          Didn’t find the answer you are looking for?{' '}
          <a
            href="#"
            title=""
            className="font-medium text-blue-600 transition-all duration-200 hover:text-blue-700 focus:text-blue-700 hover:underline"
          >
            Contact our support
          </a>
        </p>
      </div>
    </section>
  );
}

export default FAQ;
